const sendBtn = document.getElementById("sendBtn");
const recieveBtn = document.getElementById("recieveBtn");
const downloadsErrorSpan = document.getElementById("downloads-error");
const downloadsBubbleOkButton = document.getElementById('okButton');
const uploadDisabledDialogOkButton = document.getElementById("uploadDisabledDialogOkBtn");
const updateBtn = document.getElementById('update');
const usernameBtn = document.getElementById('button-username');
const downloads = document.getElementById("downloads");
const downloadAllLink = document.getElementById("downloadAllLink");
const currentUsernameText = document.getElementById('current-user-text').textContent;
const downloadText = document.getElementById('download-text').textContent;
const noDownloadsAvailableText = document.getElementById('no-downloads-text').textContent;
const downloadsRequestErrorText = document.getElementById('downloads-request-error-text').textContent;
let userId = -1;
sendBtn.onclick = function () {
    fetch("/check-upload-allowed", {
        method: "POST",
    }).then(function (res) {
        if (res.ok) {
            return res.json();
        }
    }).then(function (res) {
        if (res.allowed)
            uploadInput.click();
        else
            openBubble(uploadDisabledDialog);
    }).catch(function (err) {
        alert(err);
    });
};
recieveBtn.onclick = () => {
    openDownloadBubble(downloadBubble);
    requestAvailableDownloads();
};
updateBtn.onclick = () => {
    requestAvailableDownloads();
};
downloadsBubbleOkButton.onclick = () => {
    closeBubbles(downloadBubble);
};
uploadDisabledDialogOkButton.onclick = () => {
    closeBubbles(uploadDisabledDialog);
};
usernameBtn.onclick = () => {
    openBubble(usernameBubble);
};
function makeDownloadItem(e) {
    const downloadItem = document.createElement("li");
    downloadItem.className = "download-item";
    const downloadItemInfoContainer = document.createElement("div");
    downloadItemInfoContainer.className = "download-item-info";
    const downloadItemIcon = document.createElement("img");
    downloadItemIcon.className = "download-item-img";
    downloadItemIcon.src = `/get-icon/${e.uuid}`;
    const downloadItemName = document.createElement("span");
    downloadItemName.className = "download-item-name";
    downloadItemName.textContent = e.name;
    const downloadItemSize = document.createElement("span");
    downloadItemSize.className = "download-item-size";
    downloadItemSize.dir = "ltr";
    downloadItemSize.textContent = !e.hasSplits ? `(${getFormattedFileSize(e.size)})` : '(splits)';
    const downloadItemButton = document.createElement("a");
    downloadItemButton.className = "button-download icon-text-button";
    downloadItemButton.setAttribute("download", "");
    downloadItemButton.href = `/download/${e.uuid}`;
    const downloadItemButtonIcon = document.createElement('img');
    downloadItemButtonIcon.src = "assets/icon-download.svg";
    const downloadItemButtonText = document.createTextNode(downloadText);
    downloadItemButton.append(downloadItemButtonIcon, downloadItemButtonText);
    downloadItemInfoContainer.append(downloadItemIcon, downloadItemName, downloadItemSize, downloadItemButton);
    const colorfulLine = document.createElement("div");
    colorfulLine.className = "colorful-line";
    downloadItem.append(downloadItemInfoContainer, colorfulLine);
    return downloadItem;
}
function requestAvailableDownloads() {
    downloadsErrorSpan.style.display = "none";
    while (downloads.lastChild) {
        downloads.lastChild.remove();
    }
    fetch("/available-downloads", {
        headers: {
            "Content-Type": "application/json"
        }
    }).then(res => {
        if (res.status == 200) {
            return res.json();
        }
        else if (res.status == 401) {
            window.location.replace("/blocked");
        }
    }).then(data => {
        if (data.length == 0) {
            downloadsErrorSpan.style.display = "block";
            downloadsErrorSpan.textContent = noDownloadsAvailableText;
            downloadAllLink.style.display = 'none';
            return;
        }
        else {
            downloadsErrorSpan.style.display = "none";
            downloadAllLink.style.display = 'block';
        }
        data.forEach((e) => {
            downloads.appendChild(makeDownloadItem(e));
        });
    }).catch(error => {
        downloadsErrorSpan.style.display = "block";
        downloadsErrorSpan.textContent = downloadsRequestErrorText;
    });
}
const usernameForm = document.getElementById('usernameForm');
let storedUsername = localStorage.getItem('username');
if (!storedUsername) {
    fetch("/get-user-info", {
        method: "GET"
    }).then(function (res) {
        if (res.status === 200)
            return res.json();
        else
            throw "ERROR GETTING USER INFO";
    }).then(function (res) {
        userId = res.id;
        document.querySelector('.current-username p').textContent = `${currentUsernameText} ${res.username}`;
    }).catch(function (err) {
        alert("Error getting username");
    });
}
else {
    updateUsername(storedUsername);
}
usernameForm.addEventListener('submit', function (event) {
    event.preventDefault();
    const usernameInput = document.getElementById('usernameInput').value.trim();
    if (!usernameInput || usernameInput === '') {
        alert('Please enter a valid username.');
        return;
    }
    updateUsername(usernameInput);
    if (usernameInput !== storedUsername) {
        localStorage.setItem('username', usernameInput);
        storedUsername = usernameInput;
        document.querySelector('.current-username p').textContent = `${currentUsernameText} ${storedUsername}`;
    }
});
function updateUsername(username) {
    fetch('/update-user-name', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ username: username })
    })
        .then(response => {
        if (response.status !== 200) {
            throw new Error('Network response was not ok');
        }
        return response.json();
    })
        .then(data => {
        console.log('Username updated successfully:', data);
        if (data.changed) {
            if (data.username) {
                updateStoredUsername(data.username);
            }
            else {
                throw new Error();
            }
        }
        closeBubbles([usernameBubble]);
    })
        .catch(error => {
        console.error('Error updating username:', error);
        alert('Failed to update username');
    });
}
function updateStoredUsername(username) {
    localStorage.setItem("username", username);
    storedUsername = username;
    document.querySelector('.current-username p').textContent = `${currentUsernameText} ${username}`;
}
function setVhProperty() {
    var vh = window.innerHeight * 0.01;
    document.documentElement.style.setProperty('--vh', `${vh}px`);
}
setVhProperty();
window.addEventListener('resize', setVhProperty);
