"use strict";
const loader = document.getElementById('overlay-process');
const uploadInput = document.getElementById('uploadInput');
class UploadOperation {
    constructor(progressBar, progressText, progressSpeed) {
        this._progressTimeTrack = 0;
        this.__oldLoaded = 0;
        this.progressBar = progressBar;
        this.progressText = progressText;
        this.progressSpeed = progressSpeed;
    }
    updateProgress(loaded, total) {
        const speed = (loaded - this.__oldLoaded) / ((Date.now() - this._progressTimeTrack) * 0.001);
        this._progressTimeTrack = Date.now();
        this.__oldLoaded = loaded;
        const percent = ((loaded / total) * 100).toFixed(2);
        this.progressBar.style.width = percent + '%';
        this.progressText.textContent = percent + '%';
        this.progressSpeed.textContent = `${getFormattedFileSize(speed)} / s`;
    }
}
function showLoader() {
    loader.style.display = 'block';
}
function hideLoader() {
    document.querySelector('#plane').style.animation = 'plane-done 1.2s infinite';
    setTimeout(() => {
        loader.style.display = 'none';
        document.querySelector('#plane').style.animation = 'plane-on-progress 5s infinite';
    }, 600);
}
const progressBar = document.querySelector('#progress-bar');
const progressText = document.querySelector('#progress-text');
const progressSpeed = document.querySelector('#progress-speed');
uploadInput.addEventListener('input', function (e) {
    const xhr = new XMLHttpRequest();
    const uploadOperation = new UploadOperation(progressBar, progressText, progressSpeed);
    xhr.open("POST", "/upload/" + encodeURIComponent(this.files[0].name));
    xhr.upload.onprogress = function (event) {
        if (event.lengthComputable) {
            uploadOperation.updateProgress(event.loaded, event.total);
        }
    };
    xhr.onloadstart = function () {
        showLoader();
    };
    xhr.onloadend = function () {
        hideLoader();
    };
    xhr.onload = function () {
        if (xhr.status === 200) {
            console.log('File uploaded successfully');
        }
        else {
            console.error('Error uploading the file');
        }
    };
    xhr.onerror = function () {
        console.error('Error uploading the file');
        hideLoader();
    };
    xhr.send(this.files[0]);
});
